==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "მომხმარებლის ბარათიდან ამოშლა",
    "Hours" : "საათი",
    "Minutes" : "წუთი",
    "Deck" : "დასტა",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "{user} has shared the board %s with you." : "{user} მომხმარებელმა თქვენთან გააზიარა დაფა %s.",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Add a new stack" : "დასტის დამატება",
    "Submit" : "გაგზავნა",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
    "All Boards" : "ყველა დაფა",
    "Archived boards" : "არქივირებული დაფები",
    "Enter a card title" : "შეიყვანეთ ბარათის სახელწოდება",
    "Add card" : "ბარათის დამატება",
    "Close" : "დახურვა",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Select users or groups to share with" : "გასაზიარებლად აირჩიეთ მომხმარებლები ან ჯგუფები",
    "No matching user or group found." : "მომხმარებლები ან ჯგუფები ვერ იქნა ნაპოვნი.",
    "Loading" : "იტვირთება",
    "Edit" : "შეცვლა",
    "Share" : "გაზიარება",
    "Manage" : "მენეჯმენტი",
    "Discard share" : "გაზიარების უარყოფა",
    "Create" : "შექმნა",
    "Create a new tag" : "ახალი ტეგის შექმნა",
    "Status" : "სტატუსი",
    "Title" : "სათაური",
    "Members" : "წევრები",
    "More actions" : "მეტი ქმედება",
    "Edit board" : "დაფის შეცვლა",
    "Archive board" : "დაფის არქივირება",
    "Unarchive board" : "დაფის ამოღება",
    "Delete board" : "დაფის გაუქმება",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "დაფის გაუქმების უკუგდება - სხვა შემთხვევაში დაფა შემდეგი conjob-ის გაშვებისას წაიშლება.",
    "Create new board" : "ახალი დაფის შექმნა",
    "New board title" : "ახალი დაფის სახელი",
    "by" : "შემქმნელი",
    "Modified:" : "შეცვლილია:",
    "Created:" : "შექმნილია:",
    "Choose a tag" : "აირჩიეთ ტეგი",
    "Add a tag" : "დაამატეთ ტეგი",
    "Select tags" : "აირჩიეთ ტეგები",
    "Assign users" : "დანიშნეთ მოხმარებლები",
    "Choose a user to assign" : "აირჩიეთ მომხმარებელი",
    "Assign this card to a user" : "დაუნიშნეთ ეს ბარათი მომხმარებელს",
    "Due date" : "დროისთვის",
    "Click to set" : "დააწკაპუნეთ დასაყენებლად",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Description" : "აღწერა",
    "Saved" : "შენახულია",
    "Unsaved changes" : "შეუნახავი ცვლილებები",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Add a card description…" : "დაამატეთ ბარათის აღწერილობა...",
    "Shared boards" : "გაზიარებული დაფები",
    "Move board to archive" : "დაფის არქვიში გადატანა",
    "Create a new board" : "ახალი დაფის შექმნა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Remove user from card" : "მომხმარებლის ბარათიდან ამოშლა",
    "Hours" : "საათი",
    "Minutes" : "წუთი",
    "File already exists" : "ფაილი უკვე არსებობს",
    "Deck" : "დასტა",
    "Personal" : "პირადი",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "{user} has shared the board %s with you." : "{user} მომხმარებელმა თქვენთან გააზიარა დაფა %s.",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Done" : "დასრულებულია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Add a new stack" : "დასტის დამატება",
    "Submit" : "გაგზავნა",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
    "All Boards" : "ყველა დაფა",
    "Archived boards" : "არქივირებული დაფები",
    "Actions" : "მოქმედებები",
    "Enter a card title" : "შეიყვანეთ ბარათის სახელწოდება",
    "Add card" : "ბარათის დამატება",
    "Close" : "დახურვა",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Select users or groups to share with" : "გასაზიარებლად აირჩიეთ მომხმარებლები ან ჯგუფები",
    "Group" : "ჯგუფი",
    "Circle" : "წრე",
    "No matching user or group found." : "მომხმარებლები ან ჯგუფები ვერ იქნა ნაპოვნი.",
    "Loading" : "იტვირთება",
    "Edit" : "შეცვლა",
    "Share" : "გაზიარება",
    "Manage" : "მენეჯმენტი",
    "Discard share" : "გაზიარების უარყოფა",
    "Create" : "შექმნა",
    "Create a new tag" : "ახალი ტეგის შექმნა",
    "Status" : "სტატუსი",
    "Title" : "სათაური",
    "Members" : "წევრები",
    "More actions" : "მეტი ქმედება",
    "Edit board" : "დაფის შეცვლა",
    "Archive board" : "დაფის არქივირება",
    "Unarchive board" : "დაფის ამოღება",
    "Delete board" : "დაფის გაუქმება",
    "Undo board deletion - Otherwise the board will be deleted during the next cronjob run." : "დაფის გაუქმების უკუგდება - სხვა შემთხვევაში დაფა შემდეგი conjob-ის გაშვებისას წაიშლება.",
    "Create new board" : "ახალი დაფის შექმნა",
    "New board title" : "ახალი დაფის სახელი",
    "Cancel upload" : "ატვირთვის შეჩერება",
    "by" : "შემქმნელი",
    "Modified:" : "შეცვლილია:",
    "Created:" : "შექმნილია:",
    "Choose a tag" : "აირჩიეთ ტეგი",
    "Add a tag" : "დაამატეთ ტეგი",
    "Select tags" : "აირჩიეთ ტეგები",
    "Assign users" : "დანიშნეთ მოხმარებლები",
    "Choose a user to assign" : "აირჩიეთ მომხმარებელი",
    "Assign this card to a user" : "დაუნიშნეთ ეს ბარათი მომხმარებელს",
    "Due date" : "დროისთვის",
    "Click to set" : "დააწკაპუნეთ დასაყენებლად",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Description" : "აღწერა",
    "Saved" : "შენახულია",
    "Unsaved changes" : "შეუნახავი ცვლილებები",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add a card description…" : "დაამატეთ ბარათის აღწერილობა...",
    "Shared boards" : "გაზიარებული დაფები",
    "Move board to archive" : "დაფის არქვიში გადატანა",
    "Create a new board" : "ახალი დაფის შექმნა",
    "Settings" : "პარამეტრები"
},
"nplurals=2; plural=(n!=1);");
